//
//  RepairOrderDetailViewController.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/8.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import RxCocoa
import RxSwift


class RepairOrderDetailViewController: BaseTableViewController {

    /// RxSwift自动释放
    let disposeBag = DisposeBag()
    
    /// 悬浮View
    lazy final var suspendView: RepairOrderDetailSuspendView = {
        var suspendView = RepairOrderDetailSuspendView.instantiateFromNib() as! RepairOrderDetailSuspendView
        suspendView.frame = CGRect(x: 15, y: kHeight - kNavHeight - 80, width: kWidth - 30, height: 60)
        suspendView.operationOrderBtn.rx.controlEvent(UIControlEvents.touchUpInside).subscribe(onNext: {[weak self] (event) in
            self?.gotoEditingSonOrderVc()
        }).disposed(by: disposeBag)
        return suspendView;
    }()
    
    /// 底部（转交、完成）View
    lazy final var bottomView: RepairOrderDetailBottomView = {
        var bottomView = RepairOrderDetailBottomView.instantiateFromNib()
        bottomView.frame = CGRect(x: 0, y: getTableViewHeight(), width: kWidth, height: 70)
        return bottomView as! RepairOrderDetailBottomView;
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        setupTableView()
    }
    
    // MARK: - 设置TableView
    fileprivate func setupTableView() {
        tableView.register(UINib(nibName: RepairOrderDetailSectionView.name(), bundle: nil), forHeaderFooterViewReuseIdentifier: RepairOrderDetailSectionView.name())
        tableView.register(UINib(nibName: RepairOrderSubOrderTableViewCell.name(), bundle: nil), forCellReuseIdentifier: RepairOrderSubOrderTableViewCell.name())
        tableView.tableFooterView = bottomView
        view.addSubview(suspendView)
    }
    
    // MARK: - 获取tableView显示内容高度
    fileprivate func getTableViewHeight() ->CGFloat {
        view.layoutIfNeeded()
        return tableView.contentSize.height
    }
    
    // MARK: - 前往子工单完成界面
    fileprivate func gotoEditingSonOrderVc() {
        self.performSegue(withIdentifier: RepairOrderEditSonOrderViewController.name(), sender: nil)
    }
    
    // MARK: - UITableViewDelegate,UITableViewDataSource
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        if indexPath.section == REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue {
            let subOrderCell = tableView.dequeueReusableCell(withIdentifier: RepairOrderSubOrderTableViewCell.name(), for: indexPath)
            return subOrderCell
        }
        return super.tableView(tableView, cellForRowAt: indexPath)
    }
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if section == REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue {
            return 5
        }
        return super.tableView(tableView, numberOfRowsInSection: section)
    }
    
    override func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if indexPath.section == REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue {
            return 70
        }
        return super.tableView(tableView, heightForRowAt: indexPath)
    }

    override func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        if section == REPAIR_ORDER_DETAIL_SECTION.STATE.rawValue {
            return UIView()
        }
        let sectionView = tableView.dequeueReusableHeaderFooterView(withIdentifier: RepairOrderDetailSectionView.name())
        return sectionView
    }
    
    //cell的缩进级别，动态静态cell必须重写，否则会造成崩溃
    override func tableView(_ tableView: UITableView, indentationLevelForRowAt indexPath: IndexPath) -> Int {
        if indexPath.section == REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue {
            return super.tableView(tableView, indentationLevelForRowAt: IndexPath(row: 0, section: REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue))
        }
        return super.tableView(tableView, indentationLevelForRowAt: indexPath)
    }
    
    
    override func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        if section == REPAIR_ORDER_DETAIL_SECTION.STATE.rawValue {
            return kSectionZero
        }
        return 35
    }
    
    override func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        if section == REPAIR_ORDER_DETAIL_SECTION.SUBORDER.rawValue {
            return 10.0
        }
        return kSectionZero
    }
    
    // MARK: - 监听滑动改变悬浮View透明度
    override func scrollViewDidScroll(_ scrollView: UIScrollView) {
        let yoffset = scrollView.contentOffset.y
        if yoffset >= 0 {
            suspendView.alpha = 1 - abs(yoffset) * kSectionZero
        }
    }
}









