//
//  RepairOrderEditSonOrderViewController.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/8.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import RxSwift
import RxCocoa


class RepairOrderEditSonOrderViewController: BaseTableViewController {

    /// RxSwift自动释放
    let disposeBag = DisposeBag()
    /// 默认section高度
    let sectionHeight: CGFloat! = 30
    /// 维修前图片附件高度
    var beforAttachmentHeight: CGFloat! = 0
    /// 维修后图片附件高度
    var afterAttachmentHeight: CGFloat! = 0
    /// key
    let after: String = "after"
    let befor: String = "befor"
    
    /// 维修前图片附件
    lazy final var beforAttachmentVc: PhotoAttachmentViewController = {
        var attachmentVc = PhotoAttachmentViewController.instantiateViewController(.Function) as! PhotoAttachmentViewController
        attachmentVc.delegate = self
        return attachmentVc
    }()
    
    /// 维修后图片附件
    lazy final var afterAttachmentVc: PhotoAttachmentViewController = {
        var attachmentVc = PhotoAttachmentViewController.instantiateViewController(.Function) as! PhotoAttachmentViewController
        attachmentVc.delegate = self
        return attachmentVc
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        setupTableView()
        setupPhotoAttachmentVc()
    }
    
    // MARK: - 设置附件VC
    fileprivate func setupPhotoAttachmentVc(){
        addChildViewController(afterAttachmentVc)
        addChildViewController(beforAttachmentVc)
        beforAttachmentVc.attachmentViewModel.photoAttachments.append(PhotoAttachmentModel("add_photo", .ATTACHMENT_ADD))
        afterAttachmentVc.attachmentViewModel.photoAttachments.append(PhotoAttachmentModel("add_photo", .ATTACHMENT_ADD))
        afterAttachmentHeight = afterAttachmentVc.attachmentHeight(kONE,after)
        beforAttachmentHeight = beforAttachmentVc.attachmentHeight(kONE,befor)
    }
    
    // MARK: - TableView
    fileprivate func setupTableView() {
        tableView.register(RepairAfterAttachmentTableViewCell.classForCoder(), forCellReuseIdentifier: RepairAfterAttachmentTableViewCell.name())
        tableView.register(RepairBeforAttachmentTableViewCell.classForCoder(), forCellReuseIdentifier: RepairBeforAttachmentTableViewCell.name())
        let completeView = RepairOrderEditSonOrderCompleteView.instantiateFromNib() as! RepairOrderEditSonOrderCompleteView
        completeView.completeBtn.rx.controlEvent(UIControlEvents.touchUpInside).subscribe(onNext: {[weak self] (event) in
            self?.gotoChildBillDetailVc()
        }).disposed(by: disposeBag)
        tableView.tableFooterView = completeView
    }
    
    // MARK: - 跳转子工单详情
    fileprivate func gotoChildBillDetailVc() {
        self.performSegue(withIdentifier: RepairOrderChildBillDetailViewController.name(), sender: nil)
    }
    
    // MARK: - UITableViewDelegate,UITableViewDataSource
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        if indexPath.section == CHILD_BILL_EDIT_SECTION.BEFORATTACHMENT.rawValue {
            let beforCell = tableView.dequeueReusableCell(withIdentifier: RepairBeforAttachmentTableViewCell.name(), for: indexPath)
            beforAttachmentVc.view.frame = CGRect(x: 15, y: 8, width: kWidth - 30, height: beforAttachmentHeight)
            beforCell.contentView.addSubview(beforAttachmentVc.view)
            return beforCell
        }
        if indexPath.section == CHILD_BILL_EDIT_SECTION.AFTERATTACHMENT.rawValue {
            let afterCell = tableView.dequeueReusableCell(withIdentifier: RepairAfterAttachmentTableViewCell.name(), for: indexPath)
            afterAttachmentVc.view.frame = CGRect(x: 15, y: 8, width: kWidth - 30, height: afterAttachmentHeight)
            afterCell.contentView.addSubview(afterAttachmentVc.view)
            return afterCell
        }
        return super.tableView(tableView, cellForRowAt: indexPath)
    }
    
    override func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return kSectionZero
    }
    
    override func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        if section == CHILD_BILL_EDIT_SECTION.DESCRIBE.rawValue {
            return 10
        }
        return sectionHeight
    }
    
    override func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if indexPath.section == CHILD_BILL_EDIT_SECTION.BEFORATTACHMENT.rawValue {
            return beforAttachmentHeight + 20
        }
        if indexPath.section == CHILD_BILL_EDIT_SECTION.AFTERATTACHMENT.rawValue {
            return afterAttachmentHeight + 20
        }
        return super.tableView(tableView, heightForRowAt: indexPath)
    }
}

extension RepairOrderEditSonOrderViewController: PhotoAttachmentDelegate {
    func updatePhotoAttachment(_ height: CGFloat, _ key: String?) {
        switch key! {
        case befor:
            beforAttachmentHeight = height
            break
        case after:
            afterAttachmentHeight = height
            break
        default:
            break
        }
        tableView.reloadData()
    }
}





